#ifndef PROVIDERWINDOW_H
#define PROVIDERWINDOW_H

#include <QtGui>

class WrPlugin;

namespace Ui {
    class ProviderWindow;
}

class ProviderWindow : public QMainWindow {
    Q_OBJECT
public:
    ProviderWindow(QWidget *parent, WrPlugin *plugin);
    ~ProviderWindow();

    void refreshProviders();

protected:
    void changeEvent(QEvent *e);

private:
    Ui::ProviderWindow *ui;
    WrPlugin *plugin;
    QStandardItemModel *model;
    bool editMode;

private slots:
    void on_actionEdit_mode_triggered();
    void on_actionAdd_Custom_Search_triggered();
    void on_tblProviders_clicked(QModelIndex index);
};

#endif // PROVIDERWINDOW_H
